pub struct LaneMajor;Expand description
Lane-major view layout marker.
A lane-major view stores L contiguous lane slices of equal length. This is
useful when each lane should be processed as one long contiguous run.