pub struct Map<P>(pub P);Expand description
Lift a processor through Option or Result.
This is useful when a processor should only run on present/valid samples while preserving outer framing or error signaling. It changes control-flow shape, not block layout.
Examples
use dsp_process::{Map, Offset, SplitProcess};
let proc = Map(Offset(3));
let mut state = ();
assert_eq!(proc.process(&mut state, Some(4)), Some(7));
assert_eq!(proc.process(&mut state, None::<i32>), None);Tuple Fields
0: PTrait Implementations
Sourceimpl<X: Copy, C: SplitInplace<X, S>, S> SplitInplace<X, S> for Map<C>where
Self: SplitProcess<X, X, S>,
impl<X: Copy, C: SplitInplace<X, S>, S> SplitInplace<X, S> for Map<C>where
Self: SplitProcess<X, X, S>,
Sourceimpl<X: Copy, Y, C: SplitProcess<X, Y, S>, S> SplitProcess<Option<X>, Option<Y>, S> for Map<C>
impl<X: Copy, Y, C: SplitProcess<X, Y, S>, S> SplitProcess<Option<X>, Option<Y>, S> for Map<C>
Sourceimpl<X: Copy, Y, C: SplitProcess<X, Y, S>, S, E: Copy> SplitProcess<Result<X, E>, Result<Y, E>, S> for Map<C>
impl<X: Copy, Y, C: SplitProcess<X, Y, S>, S, E: Copy> SplitProcess<Result<X, E>, Result<Y, E>, S> for Map<C>