#[repr(transparent)]pub struct Unsplit<P>(pub P);Expand description
Marker for values that should live in the opposite half of a Split.
To be used in Split<Unsplit<P>, ()> and Split<(), Unsplit<P>>
to mark processors requiring no state and no configuration respectively.
Most users will not construct this directly and should prefer
Split::stateless and Split::stateful.
Tuple Fields
0: PTrait Implementations
impl<P: Copy> Copy for Unsplit<P>