Inplace

Trait Inplace 

pub trait Inplace<X: Copy>: Process<X> {
    // Provided method
    fn inplace(&mut self, xy: &mut [X]) { ... }
}
Inplace processing

This is a convenience trait for processors where input and output element types are identical and the computation can be expressed as overwriting a mutable slice.

See also SplitInplace for the split configuration/state form.

Provided Methods

fn inplace(&mut self, xy: &mut [X])

Process an input block into the same data as output

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl<X: Copy, T: Inplace<X>> Inplace<X> for &mut T

Source

fn inplace(&mut self, xy: &mut [X])

Implementors

Source

impl<F, X: Copy> Inplace<X> for FnProcess<F>
where Self: Process<X>,

Source

impl<T: Copy> Inplace<T> for Identity

NOP

Source

impl<T: Copy> Inplace<T> for Neg
where Self: Process<T>,

Source

impl<X: Copy, S, C: SplitInplace<X, S>> Inplace<X> for Split<C, S>

Source

impl<X: Copy, const I: usize> Inplace<X> for Rate<I>
where Self: Process<X>,

Source

impl<X: Copy, const N: usize> Inplace<X> for Buffer<[X; N]>

Source

impl<X: Copy, const N: usize> Inplace<X> for Comb<[X; N]>
where Self: Process<X>,

Source

impl<X: Copy, const N: usize> Inplace<X> for Nyquist<[X; N]>
where Self: Process<X>,

Source

impl<X: Copy> Inplace<X> for Add
where Self: Process<X>,

Source

impl<X: Copy> Inplace<X> for Butterfly
where Self: Process<X>,

Source

impl<X: Copy> Inplace<X> for Integrator<X>
where Self: Process<X>,

Source

impl<X: Copy> Inplace<X> for Mul
where Self: Process<X>,

Source

impl<X: Copy> Inplace<X> for Sub
where Self: Process<X>,