pub trait Inplace<X: Copy>: Process<X> {
// Provided method
fn inplace(&mut self, xy: &mut [X]) { ... }
}Expand description
Inplace processing
This is a convenience trait for processors where input and output element types are identical and the computation can be expressed as overwriting a mutable slice.
See also SplitInplace for the split configuration/state form.
Provided Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
Implementations on Foreign Types
Implementors
impl<F, X: Copy> Inplace<X> for FnProcess<F>where
Self: Process<X>,
impl<T: Copy> Inplace<T> for Identity
NOP